@@ -22,6 +22,8 @@
 #ifndef IAUDIO_H
 #define IAUDIO_H
 
+#include <stdint.h>
+
 class AudioConfig;
 
 class IAudio
@@ -31,7 +33,7 @@ public:
 
     virtual bool open(AudioConfig &cfg) = 0;
     virtual void reset() = 0;
-    virtual bool write() = 0;
+    virtual bool write(uint_least32_t size) = 0;
     virtual void close() = 0;
     virtual void pause() = 0;
     virtual short *buffer() const = 0;
